@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014, Brandon Nielsen
+# Copyright (c) 2016, Brandon Nielsen
 # All rights reserved.
 #
 # This software may be modified and distributed under the terms
@@ -14,7 +14,7 @@ from aniso8601.time import get_time_resolution, parse_time, parse_datetime, \
      _build_time, _split_tz
 from aniso8601.resolution import TimeResolution
 
-class TestTimeFunctions(unittest.TestCase):
+class TestTimeParserFunctions(unittest.TestCase):
     def test_get_time_resolution(self):
         self.assertEqual(get_time_resolution('01:23:45'), TimeResolution.Seconds)
         self.assertEqual(get_time_resolution('24:00:00'), TimeResolution.Seconds)
@@ -224,6 +224,24 @@ class TestTimeFunctions(unittest.TestCase):
         self.assertEqual(tzinfoobject.utcoffset(None), datetime.timedelta(hours=0))
         self.assertEqual(tzinfoobject.tzname(None), 'UTC')
 
+        with self.assertRaises(ValueError):
+            parse_time('00:00:60')
+
+        with self.assertRaises(ValueError):
+            parse_time('00:00:60Z')
+
+        with self.assertRaises(ValueError):
+            parse_time('00:00:60+00:00')
+
+        with self.assertRaises(ValueError):
+            parse_time('00:61')
+
+        with self.assertRaises(ValueError):
+            parse_time('00:61Z')
+
+        with self.assertRaises(ValueError):
+            parse_time('00:61+00:00')
+
     def test_parse_datetime(self):
         resultdatetime = parse_datetime('1981-04-05T23:21:28.512400Z')
         self.assertEqual(resultdatetime.year, 1981)
@@ -271,6 +289,24 @@ class TestTimeFunctions(unittest.TestCase):
         self.assertEqual(tzinfoobject.utcoffset(None), datetime.timedelta(hours=0))
         self.assertEqual(tzinfoobject.tzname(None), '+00:00')
 
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:00:60')
+
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:00:60Z')
+
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:00:60+00:00')
+
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:61')
+
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:61Z')
+
+        with self.assertRaises(ValueError):
+            parse_datetime('1981-04-05T00:61+00:00')
+
     def test_parse_datetime_spaceseperated(self):
         resultdatetime = parse_datetime('2004-W53-6 23:21:28.512400-12:34', ' ')
         self.assertEqual(resultdatetime.year, 2005)
@@ -357,6 +393,18 @@ class TestTimeFunctions(unittest.TestCase):
         self.assertEqual(time.second, 24)
         self.assertEqual(time.microsecond, 120000)
 
+        with self.assertRaises(ValueError):
+            _parse_time_naive('00:00:60')
+
+        with self.assertRaises(ValueError):
+            _parse_time_naive('00:00:60+00:00')
+
+        with self.assertRaises(ValueError):
+            _parse_time_naive('00:61')
+
+        with self.assertRaises(ValueError):
+            _parse_time_naive('00:61+00:00')
+
     def test_parse_hour(self):
         time = _parse_hour('01')
         self.assertEqual(time.hour, 1)
@@ -403,6 +451,18 @@ class TestTimeFunctions(unittest.TestCase):
         self.assertEqual(time.second, 27)
         self.assertEqual(time.microsecond, 402000)
 
+        with self.assertRaises(ValueError):
+            _parse_minute_time('0061')
+
+        with self.assertRaises(ValueError):
+            _parse_minute_time('0060.1')
+
+        with self.assertRaises(ValueError):
+            _parse_minute_time('00:61')
+
+        with self.assertRaises(ValueError):
+            _parse_minute_time('00:60.1')
+
     def test_parse_second_time(self):
         time = _parse_second_time('01:23:45')
         self.assertEqual(time.hour, 1)
@@ -436,6 +496,18 @@ class TestTimeFunctions(unittest.TestCase):
         self.assertEqual(time.second, 28)
         self.assertEqual(time.microsecond, 512400)
 
+        with self.assertRaises(ValueError):
+            _parse_second_time('000060')
+
+        with self.assertRaises(ValueError):
+            _parse_second_time('00:00:60')
+
+        with self.assertRaises(ValueError):
+            _parse_second_time('006100')
+
+        with self.assertRaises(ValueError):
+            _parse_second_time('00:61:00')
+
     def test_build_time(self):
         self.assertEqual(_build_time(datetime.time(hour=1), datetime.timedelta(hours=1.1, minutes=2.2, seconds=3.3)), datetime.time(hour=2, minute=8, second=15, microsecond=300000))
 
